@@ -46,7 +46,7 @@ acquires the first entry in the :class:`~ranges.RangeDict` stored on the
 :attr:`~range_streams.range_stream.RangeStream.ranges` attribute. This gates access
 to the internal ``_ranges`` attribute :class:`~ranges.RangeDict`), which takes
 into account whether the bytes in each range's
-:class:`~range_streams.range_response.RangeResponse` are exhausted
+:class:`~range_streams.response.RangeResponse` are exhausted
 or removed due to overlap with another range. See the docs for further details.
 
 Further ranges are requested by simply calling the :meth:`~range_streams.range_stream.RangeStream.add`
@@ -125,14 +125,14 @@ of the PyPNG library.
 # Get classes into package namespace but exclude from __all__ so Sphinx can access types
 
 from . import codecs, http_utils, overlaps, range_utils
-from .range_request import RangeRequest
-from .range_response import RangeResponse
 from .range_stream import RangeStream
+from .request import RangeRequest
+from .response import RangeResponse
 
 __all__ = [
     "range_stream",
-    "range_request",
-    "range_response",
+    "request",
+    "response",
     "http_utils",
     "overlaps",
     "range_utils",
@@ -146,10 +146,10 @@ __url__ = "https://github.com/lmmx/range-streams"
 __uri__ = __url__
 __email__ = "louismmx@gmail.com"
 
-_EXAMPLE_URL = (
-    "https://github.com/lmmx/range-streams/raw/master/data/example_text_file.txt"
-)
-_EXAMPLE_ZIP_URL = (
-    "https://github.com/lmmx/range-streams/raw/master/data/example_text_file.txt.zip"
-)
-_EXAMPLE_PNG_URL = "https://github.com/lmmx/range-streams/raw/master/data/red_square_rgba_semitransparent.png"
+_EXAMPLE_DATA_URL = "https://github.com/lmmx/range-streams/raw/master/data/"
+_EXAMPLE_URL = f"{_EXAMPLE_DATA_URL}example_text_file.txt"
+_EXAMPLE_ZIP_URL = f"{_EXAMPLE_DATA_URL}example_text_file.txt.zip"
+_EXAMPLE_TAR_URL = f"{_EXAMPLE_DATA_URL}data.tar"
+# _EXAMPLE_TAR_GZ_URL = f"{_EXAMPLE_TAR_URL}.gz"
+# _EXAMPLE_TAR_BZ2_URL = f"{_EXAMPLE_TAR_URL}.bz2"
+_EXAMPLE_PNG_URL = f"{_EXAMPLE_DATA_URL}red_square_rgba_semitransparent.png"
