@@ -1,6 +1,7 @@
 __all__ = [
     "EXAMPLE_ZIP_URL",
     "EXAMPLE_CONDA_URL",
+    "EXAMPLE_TAR_URL",
     "EXAMPLE_PNG_URL",
     "EXAMPLE_SEMITRANSPARENT_PNG_URL",
 ]
@@ -9,5 +10,6 @@ data_dir_URL = "https://github.com/lmmx/range-streams/raw/master/data/"
 
 EXAMPLE_ZIP_URL = f"{data_dir_URL}example_text_file.txt.zip"
 EXAMPLE_CONDA_URL = f"{data_dir_URL}tqdm-4.61.1-pyhd3eb1b0_1.conda"
+EXAMPLE_TAR_URL = f"{data_dir_URL}data.tar"
 EXAMPLE_PNG_URL = f"{data_dir_URL}red_square.png"
 EXAMPLE_SEMITRANSPARENT_PNG_URL = f"{data_dir_URL}red_square_rgba_semitransparent.png"
